[Libvir] Patch to correct spelling

Daniel P. Berrange berrange at redhat.com
Wed Jul 19 20:55:44 UTC 2006


The attached patch changes 'informations' to 'information' throughout the
codebase to fix up the English grammer. I assume its ok to commit ?

Dan.
-- 
|=- Red Hat, Engineering, Emerging Technologies, Boston.  +1 978 392 2496 -=|
|=-           Perl modules: http://search.cpan.org/~danberr/              -=|
|=-               Projects: http://freshmeat.net/~danielpb/               -=|
|=-  GnuPG: 7D3B9505   F3C9 553F A1DA 4AC2 5648 23C1 B3DF F742 7D3B 9505  -=| 
-------------- next part --------------
diff -u -r1.36 libvirt.c
--- src/libvirt.c	29 Jun 2006 22:12:47 -0000	1.36
+++ src/libvirt.c	19 Jul 2006 21:49:44 -0000
@@ -1396,7 +1396,7 @@
  * @info: pointer to a virDomainInfo structure allocated by the user
  * 
  * Extract information about a domain. Note that if the connection
- * used to get the domain is limited only a partial set of the informations
+ * used to get the domain is limited only a partial set of the information
  * can be extracted.
  *
  * Returns 0 in case of success and -1 in case of failure.
diff -u -r1.2 proxy_internal.h
--- src/proxy_internal.h	3 Jul 2006 11:12:12 -0000	1.2
+++ src/proxy_internal.h	19 Jul 2006 21:49:44 -0000
@@ -76,8 +76,8 @@
     union {
         char       str[4080];   /* extra char array */
         int        arg[1020];   /* extra int array */
-	virDomainInfo dinfo;	/* domain informations */
-	virNodeInfo   ninfo;	/* node informations */
+	virDomainInfo dinfo;	/* domain information */
+	virNodeInfo   ninfo;	/* node information */
     } extra;
 };
 typedef struct _virProxyFullPacket virProxyFullPacket;
diff -u -r1.31 virsh.c
--- src/virsh.c	26 Jun 2006 15:02:18 -0000	1.31
+++ src/virsh.c	19 Jul 2006 21:49:46 -0000
@@ -231,7 +231,7 @@
     {"syntax", "help [<command>]"},
     {"help", "print help"},
     {"desc", "Prints global help or command specific help."},
-    {"version", "Prints versionning informations."},
+    {"version", "Prints version information."},
     {NULL, NULL}
 };
 
@@ -833,7 +833,7 @@
 static vshCmdInfo info_dumpxml[] = {
     {"syntax", "dumpxml <name>"},
     {"help", "domain information in XML"},
-    {"desc", "Ouput the domain informations as an XML dump to stdout"},
+    {"desc", "Ouput the domain information as an XML dump to stdout"},
     {NULL, NULL}
 };
 
@@ -968,7 +968,7 @@
 static vshCmdInfo info_version[] = {
     {"syntax", "version"},
     {"help", "show versions"},
-    {"desc", "Display the version informations available"},
+    {"desc", "Display the version information available"},
     {NULL, NULL}
 };
 
diff -u -r1.13 virterror.c
--- src/virterror.c	26 Jun 2006 15:02:19 -0000	1.13
+++ src/virterror.c	19 Jul 2006 21:49:46 -0000
@@ -456,43 +456,43 @@
                 errmsg = "unknown OS type %s";
             break;
         case VIR_ERR_NO_KERNEL:
-            errmsg = "missing kernel informations";
+            errmsg = "missing kernel information";
             break;
         case VIR_ERR_NO_ROOT:
             if (info == NULL)
-                errmsg = "missing root device informations";
+                errmsg = "missing root device information";
             else
-                errmsg = "missing root device informations in %s";
+                errmsg = "missing root device information in %s";
             break;
         case VIR_ERR_NO_SOURCE:
             if (info == NULL)
-                errmsg = "missing source informations for device";
+                errmsg = "missing source information for device";
             else
-                errmsg = "missing source informations for device %s";
+                errmsg = "missing source information for device %s";
             break;
         case VIR_ERR_NO_TARGET:
             if (info == NULL)
-                errmsg = "missing target informations for device";
+                errmsg = "missing target information for device";
             else
-                errmsg = "missing target informations for device %s";
+                errmsg = "missing target information for device %s";
             break;
         case VIR_ERR_NO_NAME:
             if (info == NULL)
-                errmsg = "missing domain name informations";
+                errmsg = "missing domain name information";
             else
-                errmsg = "missing domain name informations in %s";
+                errmsg = "missing domain name information in %s";
             break;
         case VIR_ERR_NO_OS:
             if (info == NULL)
-                errmsg = "missing operating system informations";
+                errmsg = "missing operating system information";
             else
-                errmsg = "missing operating system informations for %s";
+                errmsg = "missing operating system information for %s";
             break;
         case VIR_ERR_NO_DEVICE:
             if (info == NULL)
-                errmsg = "missing devices informations";
+                errmsg = "missing devices information";
             else
-                errmsg = "missing devices informations for %s";
+                errmsg = "missing devices information for %s";
             break;
         case VIR_ERR_DRIVER_FULL:
             if (info == NULL)
diff -u -r1.27 xen_internal.c
--- src/xen_internal.c	3 Jul 2006 13:45:55 -0000	1.27
+++ src/xen_internal.c	19 Jul 2006 21:49:47 -0000
@@ -582,9 +582,9 @@
  * xenHypervisorGetDomInfo:
  * @conn: connection data
  * @id: the domain ID
- * @info: the place where informations should be stored
+ * @info: the place where information should be stored
  *
- * Do an hypervisor call to get the related set of domain informations.
+ * Do an hypervisor call to get the related set of domain information.
  *
  * Returns 0 in case of success, -1 in case of error.
  */
@@ -660,9 +660,9 @@
 /**
  * xenHypervisorGetDomainInfo:
  * @domain: pointer to the domain block
- * @info: the place where informations should be stored
+ * @info: the place where information should be stored
  *
- * Do an hypervisor call to get the related set of domain informations.
+ * Do an hypervisor call to get the related set of domain information.
  *
  * Returns 0 in case of success, -1 in case of error.
  */
@@ -794,7 +794,7 @@
 /**
  * xenHypervisorCheckID:
  * @domain: pointer to the domain block
- * @info: the place where informations should be stored
+ * @info: the place where information should be stored
  *
  * Do an hypervisor call to verify the domain ID is valid
  *
diff -u -r1.27 xml.c
--- src/xml.c	13 Jul 2006 22:27:31 -0000	1.27
+++ src/xml.c	19 Jul 2006 21:49:48 -0000
@@ -246,7 +246,7 @@
  * @buf: the output buffer object
  * @dev: the xenstrore internal device number
  *
- * Extract and dump in the buffer informations on the device used by the domain
+ * Extract and dump in the buffer information on the device used by the domain
  *
  * Returns 0 in case of success, -1 in case of failure
  */
@@ -357,7 +357,7 @@
  * @buf: the output buffer object
  * @dev: the xenstrore internal device number
  *
- * Extract and dump in the buffer informations on the interface used by
+ * Extract and dump in the buffer information on the interface used by
  * the domain
  *
  * Returns 0 in case of success, -1 in case of failure
@@ -457,7 +457,7 @@
  * @domain: a domain object
  * @buf: the output buffer object
  *
- * Extract the boot informations used to start that domain
+ * Extract the boot information used to start that domain
  *
  * Returns 0 in case of success, -1 in case of failure
  */
diff -u -r1.11 xs_internal.c
--- src/xs_internal.c	21 Jun 2006 12:56:19 -0000	1.11
+++ src/xs_internal.c	19 Jul 2006 21:49:48 -0000
@@ -327,9 +327,9 @@
 /**
  * xenStoreGetDomainInfo:
  * @domain: pointer to the domain block
- * @info: the place where informations should be stored
+ * @info: the place where information should be stored
  *
- * Do an hypervisor call to get the related set of domain informations.
+ * Do an hypervisor call to get the related set of domain information.
  *
  * Returns 0 in case of success, -1 in case of error.
  */


More information about the libvir-list mailing list
diff -u -r1.44 xend_internal.c
--- src/xend_internal.c	11 Jul 2006 16:57:03 -0000	1.44
+++ src/xend_internal.c	19 Jul 2006 21:49:48 -0000
@@ -443,7 +443,7 @@
  * xend_post:
  * @xend: pointer to the Xen Daemon structure
  * @path: the path used for the HTTP request
  * @ops: the informations sent for the POST
  * @content: the buffer to store the content
  * @n_content: the size of the buffer
  *
@@ -1105,20 +1105,20 @@
     value = sexpr_node(root, "domain/domid");
     if (value == NULL) {
         virXendError(xend, VIR_ERR_INTERNAL_ERROR,
-                     "domain informations incomplete, missing domid");
+                     "domain information incomplete, missing domid");
         goto error;
     }
     ret = strtol(value, NULL, 0);
     if ((ret == 0) && (value[0] != '0')) {
         virXendError(xend, VIR_ERR_INTERNAL_ERROR,
-                     "domain informations incorrect domid not numberic");
+                     "domain information incorrect domid not numberic");
         ret = -1;
     } else if (uuid != NULL) {
         char **ptr = (char **) &uuid;
 
         if (sexpr_uuid(ptr, root, "domain/uuid") == NULL) {
             virXendError(xend, VIR_ERR_INTERNAL_ERROR,
-                         "domain informations incomplete, missing uuid");
+                         "domain information incomplete, missing uuid");
         }
     }
 
@@ -1158,7 +1158,7 @@
     name = sexpr_node(root, "domain/name");
     if (name == NULL) {
       virXendError(xend, VIR_ERR_INTERNAL_ERROR,
-                   "domain informations incomplete, missing name");
+                   "domain information incomplete, missing name");
       goto error;
     }
     if (domname)
@@ -1167,7 +1167,7 @@
     dst_uuid = (char *)&uuid[0];
     if (sexpr_uuid(&dst_uuid, root, "domain/uuid") == NULL) {
       virXendError(xend, VIR_ERR_INTERNAL_ERROR,
-                   "domain informations incomplete, missing uuid");
+                   "domain information incomplete, missing uuid");
       goto error;
     }
 
@@ -1384,7 +1384,7 @@
         tmp = sexpr_node(node, "domain/image/hvm/kernel");
         if (tmp == NULL) {
             virXendError(NULL, VIR_ERR_INTERNAL_ERROR,
-                         "domain informations incomplete, missing kernel");
+                         "domain information incomplete, missing kernel");
             return(-1);
 	}
         virBufferVSprintf(buf, "    <loader>%s</loader>\n", tmp);
@@ -1407,7 +1407,7 @@
         tmp = sexpr_node(node, "domain/image/linux/kernel");
         if (tmp == NULL) {
             virXendError(NULL, VIR_ERR_INTERNAL_ERROR,
-                         "domain informations incomplete, missing kernel");
+                         "domain information incomplete, missing kernel");
             return(-1);
 	}
         virBufferVSprintf(buf, "    <kernel>%s</kernel>\n", tmp);
@@ -1461,7 +1461,7 @@
     tmp = sexpr_node(root, "domain/name");
     if (tmp == NULL) {
         virXendError(NULL, VIR_ERR_INTERNAL_ERROR,
-                     "domain informations incomplete, missing name");
+                     "domain information incomplete, missing name");
         goto error;
     }
     virBufferVSprintf(&buf, "  <name>%s</name>\n", tmp);
@@ -1524,7 +1524,7 @@
                 tmp = sexpr_node(node, "device/vbd/dev");
                 if (tmp == NULL) {
                     virXendError(NULL, VIR_ERR_INTERNAL_ERROR,
-                                 "domain informations incomplete, vbd has no dev");
+                                 "domain information incomplete, vbd has no dev");
                     goto error;
                 }
                 virBufferVSprintf(&buf, "      <target dev='%s'/>\n", tmp);
@@ -1539,7 +1539,7 @@
                 tmp = sexpr_node(node, "device/vbd/dev");
                 if (tmp == NULL) {
                     virXendError(NULL, VIR_ERR_INTERNAL_ERROR,
-                                 "domain informations incomplete, vbd has no dev");
+                                 "domain information incomplete, vbd has no dev");
                     goto error;
                 }
                 virBufferVSprintf(&buf, "      <target dev='%s'/>\n", tmp);
@@ -1748,7 +1748,7 @@
 
 error:
     virXendError(conn, VIR_ERR_INTERNAL_ERROR,
-                 "failed to parse Xend domain informations");
+                 "failed to parse Xend domain information");
     if (ret != NULL)
         virFreeDomain(conn, ret);
     return(NULL);
@@ -443,7 +443,7 @@
  * @xend: pointer to the Xen Daemon structure
  * @path: the path used for the HTTP request
- * @ops: the informations sent for the POST
+ * @ops: the information sent for the POST
  * @content: the buffer to store the content
  * @n_content: the size of the buffer